@@ -4,7 +4,7 @@ Converts a file from one format to another.
 This example shows how to write objects to a file.
 """
 
-import osmium as o
+import osmium
 
 import sys
 
@@ -13,9 +13,9 @@ if __name__ == '__main__':
         print("Usage: python convert.py <infile> <outfile>")
         sys.exit(-1)
 
-    writer = o.SimpleWriter(sys.argv[2])
+    writer = osmium.SimpleWriter(sys.argv[2])
 
-    for obj in o.FileProcessor(sys.argv[1]):
+    for obj in osmium.FileProcessor(sys.argv[1]):
         if obj.is_node():
             writer.add_node(obj)
         elif obj.is_way():
@@ -24,4 +24,3 @@ if __name__ == '__main__':
             writer.add_relation(obj)
 
     writer.close()
-
