@@ -1,30 +1,16 @@
-# SPDX-License-Identifier: BSD
+# SPDX-License-Identifier: BSD-2-Clause
 #
-# This file is part of Pyosmium.
+# This file is part of pyosmium. (https://osmcode.org/pyosmium/)
 #
-# Copyright (C) 2022 Sarah Hoffmann.
-from io import StringIO
+# Copyright (C) 2025 Sarah Hoffmann <lonvia@denofr.de> and others.
+# For a full list of authors see the git log.
 from pathlib import Path
-import sys
-import sysconfig
 import uuid
 from textwrap import dedent
 
-SRC_DIR = (Path(__file__) / '..' / '..').resolve()
-
-BUILD_DIR = "build/lib.{}-{}.{}".format(sysconfig.get_platform(),
-                                        sys.version_info[0], sys.version_info[1])
-if not (SRC_DIR / BUILD_DIR).exists():
-    BUILD_DIR = "build/lib.{}-{}".format(sysconfig.get_platform(),
-                                            sys.implementation.cache_tag)
-
-if (SRC_DIR / BUILD_DIR).exists():
-    sys.path.insert(0, str(SRC_DIR))
-    sys.path.insert(0, str(SRC_DIR / BUILD_DIR))
-
 import pytest
+import osmium
 
-import osmium as o
 
 @pytest.fixture
 def test_data_dir():
@@ -52,27 +38,30 @@ def test_data(tmp_path, to_opl):
 
     return _mkfile
 
+
 @pytest.fixture
 def opl_buffer(to_opl):
 
     def _mkbuffer(data):
-        return o.io.FileBuffer(to_opl(data).encode('utf-8'), 'opl')
+        return osmium.io.FileBuffer(to_opl(data).encode('utf-8'), 'opl')
 
     return _mkbuffer
 
+
 @pytest.fixture
 def opl_reader(opl_buffer):
 
     def _mkbuffer(data):
-        return o.io.Reader(opl_buffer(data))
+        return osmium.io.Reader(opl_buffer(data))
 
     return _mkbuffer
 
+
 @pytest.fixture
 def simple_handler(to_opl):
 
     def _run(data, node=None, way=None, relation=None, area=None, locations=False):
-        handler = o.make_simple_handler(node=node, way=way, relation=relation, area=area)
+        handler = osmium.make_simple_handler(node=node, way=way, relation=relation, area=area)
         handler.apply_buffer(to_opl(data).encode('utf-8'), 'opl', locations=locations)
 
     return _run
