@@ -1,16 +1,18 @@
-# SPDX-License-Identifier: BSD
+# SPDX-License-Identifier: BSD-2-Clause
 #
-# This file is part of Pyosmium.
+# This file is part of pyosmium. (https://osmcode.org/pyosmium/)
 #
-# Copyright (C) 2022 Sarah Hoffmann.
-
+# Copyright (C) 2025 Sarah Hoffmann <lonvia@denofr.de> and others.
+# For a full list of authors see the git log.
 from pathlib import Path
 
 import pytest
+import osmium
+
+pytestmark = pytest.mark.iterations(1)
 
 TEST_DIR = (Path(__file__) / '..').resolve()
 
-import osmium as o
 
 class DanglingReferenceBase:
     """ Base class for tests that try to keep a reference to the object
@@ -27,8 +29,8 @@ class DanglingReferenceBase:
         self.refkeeper.append((obj, func))
 
     def test_keep_reference(self):
-        h = o.make_simple_handler(node=self.node, way=self.way,
-                                  relation=self.relation, area=self.area)
+        h = osmium.make_simple_handler(node=self.node, way=self.way,
+                                       relation=self.relation, area=self.area)
         h.apply_file(TEST_DIR / 'example-test.osc')
         assert self.refkeeper
 
@@ -40,7 +42,7 @@ class DanglingReferenceBase:
             repr(obj)
 
     def test_keep_reference_generator(self):
-        for obj in o.FileProcessor(TEST_DIR / 'example-test.osc').with_areas():
+        for obj in osmium.FileProcessor(TEST_DIR / 'example-test.osc').with_areas():
             if obj.type_str() == 'n' and self.node is not None:
                 self.node(obj)
             elif obj.type_str() == 'w' and self.way is not None:
@@ -65,63 +67,75 @@ class TestKeepNodeRef(DanglingReferenceBase):
     def node(self, n):
         self.keep(n, lambda n: n.id)
 
+
 class TestKeepWayRef(DanglingReferenceBase):
 
     def way(self, w):
         self.keep(w, lambda n: n.id)
 
+
 class TestKeepRelationRef(DanglingReferenceBase):
 
     def relation(self, r):
         self.keep(r, lambda n: n.id)
 
+
 class TestKeepAreaRef(DanglingReferenceBase):
 
     def area(self, a):
         self.keep(a, lambda n: n.id)
 
+
 class TestKeepNodeTagsRef(DanglingReferenceBase):
 
     def node(self, n):
         self.keep(n.tags, lambda t: 'foo' in t)
 
+
 class TestKeepWayTagsRef(DanglingReferenceBase):
 
     def way(self, w):
         self.keep(w.tags, lambda t: 'foo' in t)
 
+
 class TestKeepRelationTagsRef(DanglingReferenceBase):
 
     def relation(self, r):
         self.keep(r.tags, lambda t: 'foo' in t)
 
+
 class TestKeepAreaTagsRef(DanglingReferenceBase):
 
     def area(self, a):
         self.keep(a.tags, lambda t: 'foo' in t)
 
+
 class TestKeepTagListIterator(DanglingReferenceBase):
 
     def node(self, n):
         self.keep(n.tags.__iter__(), lambda t: next(t))
 
+
 class TestKeepOuterRingIterator(DanglingReferenceBase):
 
     def area(self, r):
         self.keep(r.outer_rings(), lambda t: next(t))
 
+
 class TestKeepOuterRing(DanglingReferenceBase):
 
     def area(self, r):
         for ring in r.outer_rings():
             self.keep(ring, lambda t: len(t))
 
+
 class TestKeepInnerRingIterator(DanglingReferenceBase):
 
     def area(self, r):
         for ring in r.outer_rings():
             self.keep(r.inner_rings(ring), lambda t: next(t))
 
+
 class TestKeepInnerRing(DanglingReferenceBase):
 
     def area(self, r):
@@ -129,13 +143,13 @@ class TestKeepInnerRing(DanglingReferenceBase):
             for inner in r.inner_rings(outer):
                 self.keep(inner, lambda t: len(t))
 
+
 class TestKeepRelationMemberIterator(DanglingReferenceBase):
 
     def relation(self, r):
         self.keep(r.members, lambda t: next(t))
 
 
-
 class NotADanglingReferenceBase:
     """ Base class for tests that ensure that the callback does not
         bail out because of dangling references when POD types are
@@ -152,8 +166,8 @@ class NotADanglingReferenceBase:
         self.refkeeper.append((obj, func))
 
     def test_keep_reference(self):
-        h = o.make_simple_handler(node=self.node, way=self.way,
-                                  relation=self.relation, area=self.area)
+        h = osmium.make_simple_handler(node=self.node, way=self.way,
+                                       relation=self.relation, area=self.area)
         h.apply_file(TEST_DIR / 'example-test.pbf')
         assert self.refkeeper
 
@@ -161,7 +175,7 @@ class NotADanglingReferenceBase:
             func(obj)
 
     def test_keep_reference_generator(self):
-        for obj in o.FileProcessor(TEST_DIR / 'example-test.pbf').with_areas():
+        for obj in osmium.FileProcessor(TEST_DIR / 'example-test.pbf').with_areas():
             if obj.is_node() and self.node is not None:
                 self.node(obj)
             elif obj.is_way() and self.way is not None:
@@ -180,7 +194,8 @@ class NotADanglingReferenceBase:
 class TestKeepLocation(NotADanglingReferenceBase):
 
     def node(self, n):
-        self.keep(n.location, lambda l: l.x)
+        self.keep(n.location, lambda loc: loc.x)
+
 
 class TestKeepNode(NotADanglingReferenceBase):
 
@@ -188,6 +203,7 @@ class TestKeepNode(NotADanglingReferenceBase):
         for t in n.tags:
             self.keep(t, lambda t: t.k)
 
+
 class TestKeepMember(NotADanglingReferenceBase):
 
     def relation(self, r):
