@@ -1,13 +1,16 @@
-# SPDX-License-Identifier: BSD
+# SPDX-License-Identifier: BSD-2-Clause
 #
-# This file is part of Pyosmium.
+# This file is part of pyosmium. (https://osmcode.org/pyosmium/)
 #
-# Copyright (C) 2022 Sarah Hoffmann.
+# Copyright (C) 2025 Sarah Hoffmann <lonvia@denofr.de> and others.
+# For a full list of authors see the git log.
 """
 Tests for all examples.
 """
 from pathlib import Path
 
+import pytest
+
 TEST_DIR = (Path(__file__) / '..').resolve()
 TEST_FILE = TEST_DIR / 'example-test.pbf'
 TEST_DIFF = TEST_DIR / 'example-test.osc'
@@ -24,6 +27,7 @@ def run_example(name, *args):
 
 
 def test_amenity_list(capsys):
+    pytest.importorskip("shapely")
     assert 0 == run_example("amenity_list", TEST_FILE)
 
     output = capsys.readouterr().out.splitlines()
@@ -56,14 +60,14 @@ def test_osm_diff_stats(capsys):
     output = capsys.readouterr().out.splitlines()
 
     assert output == ['Nodes added: 305',
-                     'Nodes modified: 192',
-                     'Nodes deleted: 20',
-                     'Ways added: 31',
-                     'Ways modified: 93',
-                     'Ways deleted: 0',
-                     'Relations added: 0',
-                     'Relations modified: 0',
-                     'Relations deleted: 0']
+                      'Nodes modified: 192',
+                      'Nodes deleted: 20',
+                      'Ways added: 31',
+                      'Ways modified: 93',
+                      'Ways deleted: 0',
+                      'Relations added: 0',
+                      'Relations modified: 0',
+                      'Relations deleted: 0']
 
 
 def test_osm_file_stats(capsys):
