@@ -2,17 +2,17 @@
 #
 # This file is part of pyosmium. (https://osmcode.org/pyosmium/)
 #
-# Copyright (C) 2024 Sarah Hoffmann <lonvia@denofr.de> and others.
+# Copyright (C) 2025 Sarah Hoffmann <lonvia@denofr.de> and others.
 # For a full list of authors see the git log.
 import pytest
 
-import osmium as o
-
+import osmium
 from helpers import IDCollector
 
+
 def test_id_filter_bad_argument():
     with pytest.raises(TypeError):
-        o.filter.IdFilter(None)
+        osmium.filter.IdFilter(None)
 
 
 def test_id_filter_simple(opl_reader):
@@ -25,6 +25,6 @@ def test_id_filter_simple(opl_reader):
 
     ids = IDCollector()
 
-    o.apply(opl_reader(data), o.filter.IdFilter([2, 5, 200, 201]), ids)
+    osmium.apply(opl_reader(data), osmium.filter.IdFilter([2, 5, 200, 201]), ids)
 
     assert ids.nodes == [2, 200]
