@@ -1,16 +1,17 @@
-# SPDX-License-Identifier: BSD
+# SPDX-License-Identifier: BSD-2-Clause
 #
-# This file is part of Pyosmium.
+# This file is part of pyosmium. (https://osmcode.org/pyosmium/)
 #
-# Copyright (C) 2023 Sarah Hoffmann.
+# Copyright (C) 2025 Sarah Hoffmann <lonvia@denofr.de> and others.
+# For a full list of authors see the git log.
 """ Tests for the pyosmium-get-changes script.
 """
-from pathlib import Path
 from textwrap import dedent
+import uuid
 
-import pytest
 import osmium.replication.server
-import osmium as o
+import osmium
+from osmium.tools.pyosmium_get_changes import pyosmium_get_changes
 
 from helpers import IDCollector
 
@@ -22,18 +23,8 @@ except ImportError:
 
 class TestPyosmiumGetChanges:
 
-    @pytest.fixture(autouse=True)
-    def setup(self):
-        self.script = dict()
-
-        filename = (Path(__file__) / ".." / ".." / "tools"/ "pyosmium-get-changes").resolve()
-        with filename.open("rb") as f:
-            exec(compile(f.read(), str(filename), 'exec'), self.script)
-
-
     def main(self, httpserver, *args):
-        return self.script['main'](['--server', httpserver.url_for('')] + list(args))
-
+        return pyosmium_get_changes(['--server', httpserver.url_for('')] + list(args))
 
     def test_init_id(self, capsys, httpserver):
         assert 0 == self.main(httpserver, '-I', '453')
@@ -42,7 +33,6 @@ class TestPyosmiumGetChanges:
 
         assert output == '453'
 
-
     def test_init_date(self, capsys, httpserver):
         httpserver.expect_request('/state.txt').respond_with_data(dedent("""\
                     sequenceNumber=100
@@ -58,22 +48,19 @@ class TestPyosmiumGetChanges:
 
         assert output == '-1'
 
-
     def test_init_to_file(self, tmp_path, httpserver):
-        fname = tmp_path / 'db.seq'
+        fname = tmp_path / f"{uuid.uuid4()}.seq"
 
         assert 0 == self.main(httpserver, '-I', '453', '-f', str(fname))
         assert fname.read_text() == '453'
 
-
     def test_init_from_seq_file(self, tmp_path, httpserver):
-        fname = tmp_path / 'db.seq'
+        fname = tmp_path / f"{uuid.uuid4()}.seq"
         fname.write_text('453')
 
         assert 0 == self.main(httpserver, '-f', str(fname))
         assert fname.read_text() == '453'
 
-
     def test_init_date_with_cookie(self, capsys, tmp_path, httpserver):
         httpserver.expect_request('/state.txt').respond_with_data(dedent("""\
                     sequenceNumber=100
@@ -95,9 +82,8 @@ class TestPyosmiumGetChanges:
 
         assert output == '-1'
 
-
     def test_get_simple_update(self, tmp_path, httpserver):
-        outfile = tmp_path / 'outfile.opl'
+        outfile = tmp_path / f"{uuid.uuid4()}.opl"
 
         httpserver.expect_request('/state.txt').respond_with_data(dedent("""\
                     sequenceNumber=454
@@ -114,7 +100,7 @@ class TestPyosmiumGetChanges:
                               '-I', '453', '-o', str(outfile))
 
         ids = IDCollector()
-        o.apply(str(outfile), ids)
+        osmium.apply(str(outfile), ids)
 
         assert ids.nodes == [12, 13]
         assert ids.ways == [2]
